# Generated by Django 4.2.15 on 2024-10-28 02:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('artd_order', '0007_orderpaymentmethod'),
    ]

    operations = [
        migrations.AddField(
            model_name='order',
            name='order_payment_method',
            field=models.ForeignKey(blank=True, help_text='Order payment method', null=True, on_delete=django.db.models.deletion.CASCADE, to='artd_order.orderpaymentmethod', verbose_name='Order payment method'),
        ),
    ]



from django.utils.translation import gettext_lazy as _

ORDER_DELIVERY_METHODS = (
    (
        0,
        "default",
        _("Default"),
    ),
    (
        1,
        "pickup",
        _("Pickup"),
    ),
    (
        2,
        "post",
        _("Post"),
    ),
    (
        3,
        "other",
        _("Other"),
    ),
    (
        4,
        "courier",
        _("Courier"),
    ),
)



# Generated by Django 5.0.1 on 2024-03-10 18:47

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_order", "0005_orderadress_json_data_orderstatus_json_data_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="order_status",
            field=models.ForeignKey(
                default=0,
                help_text="Order status",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_order.orderstatus",
                verbose_name="Order status",
            ),
        ),
        migrations.AlterField(
            model_name="orderadress",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderdeliverymethod",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderpaymenthistory",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderproduct",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderstatus",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
        migrations.AlterField(
            model_name="orderstatushistory",
            name="json_data",
            field=models.JSONField(
                blank=True,
                default=dict,
                help_text="JSON data",
                null=True,
                verbose_name="JSON data",
            ),
        ),
    ]



# Generated by Django 5.0.1 on 2025-03-23 00:53

import django.db.models.deletion
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_order", "0008_order_order_payment_method"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name="order",
            name="created_by",
            field=models.ForeignKey(
                blank=True,
                help_text="Created by",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to=settings.AUTH_USER_MODEL,
                verbose_name="Created by",
            ),
        ),
    ]



from django.utils.translation import gettext_lazy as _

ORDER_STATUSES = (
    (
        0,
        "new",
        _("New"),
    ),
    (
        1,
        "in_progress",
        _("In progress"),
    ),
    (
        2,
        "done",
        _("Done"),
    ),
    (
        3,
        "canceled",
        _("Canceled"),
    ),
    (
        4,
        "closed",
        _("Closed"),
    ),
    (
        5,
        "pending_payment",
        _("Pending payment"),
    ),
    (
        6,
        "failed_payment",
        _("Failed payment"),
    ),
    (
        7,
        "success_payment",
        _("Success payment"),
    ),
)



# Generated by Django 4.2.15 on 2024-10-28 02:05

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('artd_partner', '0007_position_partner'),
        ('artd_order', '0006_alter_order_json_data_alter_order_order_status_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='OrderPaymentMethod',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('created_at', models.DateTimeField(auto_now_add=True, help_text='Date time on which the object was created.', verbose_name='Created at')),
                ('updated_at', models.DateTimeField(auto_now=True, help_text='Date time on which the object was last updated.', verbose_name='Updated at')),
                ('status', models.BooleanField(default=True, help_text='Status of the object.', verbose_name='Status')),
                ('source', models.CharField(blank=True, help_text='Source of the object.', max_length=100, null=True, verbose_name='Source')),
                ('external_id', models.CharField(blank=True, help_text='External ID of the object.', max_length=100, null=True, verbose_name='External ID')),
                ('json_data', models.JSONField(blank=True, default=dict, help_text='JSON data', null=True, verbose_name='JSON data')),
                ('name', models.CharField(help_text='Name', max_length=100, verbose_name='Name')),
                ('code', models.CharField(help_text='Code', max_length=100, unique=True, verbose_name='Code')),
                ('partner', models.ForeignKey(help_text='Partner', on_delete=django.db.models.deletion.CASCADE, to='artd_partner.partner', verbose_name='Partner')),
            ],
            options={
                'verbose_name': 'Order Payment Method',
                'verbose_name_plural': 'Order Payment Methods',
                'unique_together': {('partner', 'code')},
            },
        ),
    ]



# Generated by Django 5.0.1 on 2024-03-10 06:10

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_location", "0002_alter_city_created_at_alter_city_status_and_more"),
        ("artd_order", "0002_order_external_id_order_source_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="orderadress",
            name="city",
            field=models.ForeignKey(
                help_text="City",
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_location.city",
                verbose_name="City",
            ),
        ),
    ]



# Generated by Django 5.0.1 on 2024-03-10 15:06

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_order", "0003_alter_orderadress_city"),
        ("artd_promotion", "0005_alter_promotionrule_categories_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="coupon_code",
            field=models.ForeignKey(
                blank=True,
                help_text="Coupon code",
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                to="artd_promotion.coupon",
                verbose_name="Coupon code",
            ),
        ),
    ]



# Generated by Django 5.0.1 on 2024-03-10 15:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("artd_order", "0004_alter_order_coupon_code"),
    ]

    operations = [
        migrations.AddField(
            model_name="orderadress",
            name="json_data",
            field=models.JSONField(
                blank=True, help_text="JSON data", null=True, verbose_name="JSON data"
            ),
        ),
        migrations.AddField(
            model_name="orderstatus",
            name="json_data",
            field=models.JSONField(
                blank=True, help_text="JSON data", null=True, verbose_name="JSON data"
            ),
        ),
        migrations.AddField(
            model_name="orderstatushistory",
            name="json_data",
            field=models.JSONField(
                blank=True, help_text="JSON data", null=True, verbose_name="JSON data"
            ),
        ),
    ]



from django.db.models.signals import pre_save, post_migrate
from django.dispatch import receiver
from artd_order.models import Order


@receiver(pre_save, sender=Order)
def set_increment_id(sender, instance, **kwargs):
    # Verifica si es una nueva instancia (no tiene un ID asignado)
    if instance.pk is None:
        # Obtiene el último increment_id para el partner y lo incrementa en uno
        last_order = (
            Order.objects.filter(partner=instance.partner)
            .order_by("-increment_id")
            .first()
        )
        if last_order:
            instance.increment_id = last_order.increment_id + 1
        else:
            # Si es el primer Order para el Partner, establece el increment_id en 1
            instance.increment_id = 1


@receiver(post_migrate)
def execute_after_migrations(sender, **kwargs):
    from artd_modules.utils import create_or_update_module_row

    create_or_update_module_row(
        slug="artd_order",
        name="Artd Order",
        description="Artd Order",
        version="1.0.10",
        is_plugin=False,
    )



from django.apps import AppConfig
from django.utils.translation import gettext_lazy as _


class ArtdOrderConfig(AppConfig):
    default_auto_field = "django.db.models.BigAutoField"
    name = "artd_order"
    verbose_name = _("Order")

    def ready(self):
        import artd_order.signals



from django.core.management.base import BaseCommand

from artd_order.data.order_delivery_methods import ORDER_DELIVERY_METHODS as METHODS
from artd_order.models import OrderDeliveryMethod
from artd_partner.models import Partner


class Command(BaseCommand):
    help = "Create order delivery methods in the database."

    def add_arguments(self, parser):
        parser.add_argument(
            "partner_slug", type=str, help="Mandatory value for partner_slug"
        )

    def handle(self, *args, **kwargs):
        partner_slug = kwargs["partner_slug"]
        if Partner.objects.filter(partner_slug=partner_slug).count() > 0:
            partner = Partner.objects.get(partner_slug=partner_slug)
            for method in METHODS:
                if OrderDeliveryMethod.objects.filter(id=method[0]).count() == 0:
                    OrderDeliveryMethod.objects.create(
                        id=method[0],
                        partner=partner,
                        delivery_method_code=method[1],
                        delivery_method_description=method[2],
                    )
                    self.stdout.write(self.style.SUCCESS(f"{method[2]} was created"))
                else:
                    status_obj = OrderDeliveryMethod.objects.get(
                        id=method[0],
                    )
                    status_obj.delivery_method_code = method[1]
                    status_obj.delivery_method_description = method[2]
                    status_obj.save()
                    self.stdout.write(self.style.WARNING(f"{method[2]} was updated"))
        else:
            self.stdout.write(
                self.style.ERROR(f"Partner with slug {partner_slug} does not exist")
            )
